import { ToolbarButton } from '@jupyterlab/apputils';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { ITranslator } from '@jupyterlab/translation';
import { listIcon, folderIcon } from '@jupyterlab/ui-components';
import { FileSystemDrive } from './drive';
/**
 * Initialization data for the jupyterlab-filesystem-access extension.
 */
const plugin = {
    id: 'jupyterlab-filesystem-access:plugin',
    requires: [IFileBrowserFactory, ITranslator],
    autoStart: true,
    activate: (app, browser, translator) => {
        if (!window.showDirectoryPicker) {
            // bail if the browser does not support the File System API
            console.warn('The File System Access API is not supported in this browser.');
            return;
        }
        const { serviceManager } = app;
        const { createFileBrowser } = browser;
        const trans = translator.load('jupyterlab-filesystem-access');
        const drive = new FileSystemDrive();
        serviceManager.contents.addDrive(drive);
        const widget = createFileBrowser('jp-filesystem-browser', {
            driveName: drive.name
        });
        widget.title.caption = trans.__('Local File System');
        widget.title.icon = listIcon;
        const openDirectoryButton = new ToolbarButton({
            icon: folderIcon,
            onClick: async () => {
                const fileHandle = await window.showDirectoryPicker();
                if (fileHandle) {
                    drive.rootHandle = fileHandle;
                }
            },
            tooltip: trans.__('Open a new folder')
        });
        widget.toolbar.insertItem(0, 'open-directory', openDirectoryButton);
        app.shell.add(widget, 'left');
    }
};
export default plugin;
